import * as Core from '@anthropic-ai/sdk/core';
export declare class APIResource {
    protected _client: Core.APIClient;
    constructor(client: Core.APIClient);
}
//# sourceMappingURL=resource.d.ts.map