import { APIResource } from '@anthropic-ai/sdk/resource';
import * as ToolsAPI from '@anthropic-ai/sdk/resources/beta/tools/tools';
export declare class Beta extends APIResource {
    tools: ToolsAPI.Tools;
}
export declare namespace Beta {
    export import Tools = ToolsAPI.Tools;
}
//# sourceMappingURL=beta.d.ts.map