// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from '@anthropic-ai/sdk/resource';
import { ToolsBetaMessageStream } from '@anthropic-ai/sdk/lib/ToolsBetaMessageStream';
export { ToolsBetaMessageStream } from '@anthropic-ai/sdk/lib/ToolsBetaMessageStream';
export class Messages extends APIResource {
    create(body, options) {
        return this._client.post('/v1/messages?beta=tools', {
            body,
            timeout: 600000,
            ...options,
            headers: { 'anthropic-beta': 'tools-2024-05-16', ...options?.headers },
            stream: body.stream ?? false,
        });
    }
    /**
     * Create a Message stream
     */
    stream(body, options) {
        return ToolsBetaMessageStream.createMessage(this, body, options);
    }
}
(function (Messages) {
})(Messages || (Messages = {}));
//# sourceMappingURL=messages.mjs.map